@@ -1,11 +1,11 @@
-/* mcparameters.h -- This file is part of Archimedes release 0.0.2.
+/* mcparameters.h -- This file is part of Archimedes release 0.0.6.
    Archimedes is a simulator for Submicron 2D Silicon/GaAs
    Devices. It implements the Monte Carlo method
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
    of effective potential method.
 
-   Copyright (C) 2004, 2005 Jean Michel Sellier <sellier@dmi.unict.it>
+   Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 
 // ######################################################
 // Created on 05 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 27 Jan.2005, Siracusa, J.M.Sellier
+// Last modif. : 24 Dec.2006, Siracusa, J.M.Sellier
 // ######################################################
 
 // Definition of the variables needed for taking into
@@ -208,7 +208,10 @@ MCparameters(void)
     finalenergy=initialenergy;
     sef=sqrt(finalenergy*(1.+AF[2]*finalenergy));
     SWK[2][7][ie]=SWK[2][6][ie]+aco*sef*dos2*(1.+2.*AF[2]*finalenergy);
-  }
+// ==================
+// --->  } <--- This is a bug! Removed by J.M.Sellier on 24 dec.2006 (SR)
+// (Thanks to Kun-Yuan Xu who helped me in finding it!)
+// ==================
 // Impurity scattering
     finalenergy=initialenergy;
     sef=sqrt(finalenergy*(1.+AF[2]*finalenergy));
@@ -217,7 +220,7 @@ MCparameters(void)
     wk=bimp/qq*sef*dos2*(1.+2.*AF[2]*finalenergy);
     if(wk>1.e14) wk=1.e14;
     SWK[2][8][ie]=SWK[2][7][ie]+wk;
-
+  } // <--- this is the correct place for the symbol } (J.M.Sellier,24/12/2006)
 // Evalutation of gamma
   GM=SWK[1][6][1];
   for(ie=1;ie<=DIME;ie++){
